@@ -87,7 +87,7 @@ RcppExport SEXP frailty_GRF_LDTFP(SEXP nburn_, SEXP nsave_, SEXP nskip_, SEXP nd
 	
 	// things to save;
 	NumericVector betaArray(nsave*ntlr*ptf);
-	arma::cube betatf_save(betaArray.begin(), ptf, ntlr, nsave, false);
+	arma::cube betatf_save(betaArray.begin(), ptf, ntlr, nsave, false, true);
   arma::mat beta_save(pce, nsave);
 	NumericVector sigma2_save(nsave);
 	NumericVector alpha_save(nsave);
